require 'uu/os/qos/qos_handler'
require 'uu/os/rest'
require 'uu/os/uesuri'

module UU
  module OS
   

      # UES Search service.
      module Search
        extend self

        # Service path
        PATH = 'ues/core/search/UESSearch'

        # This command checks the existence of an artifact or an aggregated object in the system.
        # It doesn't check any business rules, so it never throws an application exception (system
        # exceptions like web services connection problems can still occur). If the current user
        # has an access to the territory specified in objectUri, the command returns true if there
        # is an aggregated object or an artifact with UESURI object_uri. If false is returned in
        # this case, it is safe to assume the UESURI is not used and it is free to use (Bear in mind
        # this applies only in the moment of the command call. ). If the current user doesn't have
        # an access to the territory or the territory doesn't exist, the command always returns false.
        #
        # @param [String, UU::OS::UESURI] object_uri UESURI of an artifact or an aggregated object
        #
        # @return [Boolean] True if object exists, else false
        def exists(object_uri)
          svc = UU::OS::REST::RemoteClient.new(Search)
          UU::OS::QoS::QoSHandler.auto_retry do
            res = svc.get('exists', object_uri)
            return (res == 'true') || (res == '"true"') 
          end
        end

      end

    end

end
