require 'uu/os/rest/dto'
require 'uu/os/uesuri'

# Module Unicorn Universe.
module UU
  # Module Application Deployment Kit.
  module OS
    # Module Visual Use Case.
    module VisualUseCase
      # @see VisualUseCase#get_attributes
      class VisualUseCaseAttributes < UU::OS::REST::DTO

        # The name of the visual use case. Never nil.
        attr_accessor :name

        # The code of the visual use case. Never nil.
        attr_accessor :code

        # The description of the visual use case. Never nil.
        attr_accessor :description

        # The normalized UESURI of the visual use case. Never nil.
        attr_accessor :uri

        # URI of the visual use case's container.
        attr_accessor :location_uri

        # URI of the organizational unit in which the visual use case lies.
        attr_accessor :organizational_unit_uri

        # URI of the company where the visual use case is located.
        # @deprecated
        attr_accessor :company_uri

        # URI of the meta artifact. Never nil.
        attr_accessor :meta_artifact_uri

        # URI of the competent for visual use case.
        attr_accessor :competent_role_uri

        # Security level of the visual use case. Never nil.
        #
        # @see UU::OS::Artifact::SecurityLevel
        attr_accessor :security_level

        # The creation stamp of the visual use case. Never nil.
        attr_accessor :creation_stamp

        # The creation time of the visual use case. Never nil.
        attr_accessor :creation_time

        # The modification time of the visual use case. Never nil.
        attr_accessor :modification_stamp

        # The modification stamp of the visual use case. Never nil.
        attr_accessor :modification_time

        # Version of the visual use case. Never nil.
        attr_accessor :version

        # URI of the visual use case's icon. If nil is set, the visual use case uses icon from meta artifact.
        attr_accessor :icon_uri

        # Path at which the controller will be deployed
        attr_accessor :controller_url_path

        # Class to look for when executing this VUC
        attr_accessor :controller_class

        # Engine used for this VUC
        #
        # @see UU::OS::VisualUseCase::ControllerEngine
        attr_accessor :controller_engine

        # Revision of the controller - its attachment
        attr_accessor :controller_revision

        # URI of the entity type of the visual use case (@see cz.ues.platform.sysc.entitytype.UESEntityType for more info). Never nil.
        attr_accessor :entity_type_uri

        # @deprecated Always returns nil.
        attr_accessor :artifact_type
        
        # Defines whether the primarily displayed content
        attr_accessor :component_content
        
        # @deprecated Always returns nil.
        def artifact_type
          nil
        end

        # @deprecated Input value is ignored, nil is always assumed.
        def artifact_type=(val)
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def location_uri
          attributes[:locationUri]
        end

        def location_uri=(val)
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end

        def organizational_unit_uri
          attributes[:organizationalUnitUri]
        end

        def organizational_unit_uri=(val)
          if val
            attributes[:organizationalUnitUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitUri] = nil
          end
        end

        # @deprecated
        def company_uri
          attributes[:companyUri]
        end

        # @deprecated
        def company_uri=(val)
          if val
            attributes[:companyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:companyUri] = nil
          end
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def creation_stamp
          attributes[:creationStamp]
        end

        def creation_stamp=(val)
          attributes[:creationStamp] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          if val.kind_of?String
            attributes[:creationTime] = Time.parse(val)
          else
            attributes[:creationTime] = val
          end
        end

        def modification_stamp
          attributes[:modificationStamp]
        end

        def modification_stamp=(val)
          attributes[:modificationStamp] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          if val.kind_of?String
            attributes[:modificationTime] = Time.parse(val)
          else
            attributes[:modificationTime] = val
          end
        end

        # @deprecated Use {VisualUseCaseAttributes#version} instead.
        def revision
          attributes[:version]
        end

        # @deprecated Use {VisualUseCaseAttributes#version} instead.
        def revision=(val)
          attributes[:version] = val
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        def controller_url_path
          attributes[:controllerUrlPath]
        end

        def controller_url_path=(val)
          attributes[:controllerUrlPath] = val
        end

        def controller_class
          attributes[:controllerClass]
        end

        def controller_class=(val)
          attributes[:controllerClass] = val
        end

        def controller_revision
          attributes[:controllerRevision]
        end

        def controller_revision=(val)
          attributes[:controllerRevision] = val
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

        def controller_engine
          attributes[:controllerEngine]
        end

        def controller_engine=(val)
          attributes[:controllerEngine] = val
        end

        def component_content
          attributes[:componentContent]
        end

        def component_content=(val)
          attributes[:componentContent] = val
        end

      end
    end
  end

end
